@@ -127,3 +127,10 @@ impl<'s> IntoIterator for &'s ArrayOfTables {
         self.iter()
     }
 }
+
+impl std::fmt::Display for ArrayOfTables {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        // HACK: Without the header, we don't really have a proper way of printing this
+        self.clone().into_array().fmt(f)
+    }
+}
